package com.muyu.cloud.mart.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.cloud.mart.mapper.ConnectorMapper;
import com.muyu.cloud.mart.service.ConnectorService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.domain.Connector;
import com.muyu.domain.ConnectorUser;
import com.muyu.domain.req.ConnectorUserReq;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * @Author：chaiyapeng
 * @Package：com.muyu.cloud.mart.service.impl
 * @Project：cloud-mart
 * @name：ConnectorServiceImpl
 * @Date：2024/8/26 10:24
 */
@Service
public class ConnectorServiceImpl extends ServiceImpl<ConnectorMapper, Connector> implements ConnectorService {
    @Autowired
    private ConnectorMapper connectorMapper;
//    @Autowired
//    private FastFileStorageClient fastFileStorageClient;

    /**
     * 接口列表
     * @param connector
     * @return
     */
    @Override
    public Result findConnectorList(Connector connector) {
        QueryWrapper<Connector> wrapper = new QueryWrapper<>();
        if (connector.getConnectorName()!=null && !connector.getConnectorName().equals("")){
            wrapper.like("connector_name",connector.getConnectorName());
        }
        List<Connector> connectors = connectorMapper.selectList(wrapper);
        return Result.success(connectors);
    }

    @Override
    public Result updateConnector(Connector connector) {
        connector.setConnectorTime(new Date());
        Integer i = connectorMapper.updateConnector(connector);
        if (i>0){
            return Result.success(i,"更新成功");
        }
        return Result.error("更新失败");
    }

    @Override
    public Result addConnector(Connector connector) {
        connector.setConnectorTime(new Date());
        connector.setConnectorStatus(0);
        Integer i = connectorMapper.insert(connector);
        if (i>0){
            return Result.success(i,"添加成功");
        }
        return Result.error("添加失败");
    }

    @Override
    public Result getDeleteConnector(Long connectorId) {
        Long i = connectorMapper.getDeleteConnector(connectorId);
        if (i>0){
            return Result.success(i,"删除成功");
        }
        return Result.error("删除失败");
    }

    @Override
    public Result<List<ConnectorUser>> findConnectorUserList(ConnectorUserReq connectorUserReq) {
        //获取当前用户ID
        Long userId = SecurityUtils.getUserId();
        connectorUserReq.setUserId(userId);
        List<ConnectorUser> list = connectorMapper.findConnectorUserList(connectorUserReq);
        return Result.success(list);
    }

    @Override
    public Result findApiList(Connector connector) {
        List<Connector> list = connectorMapper.findApiList(connector);
        return Result.success(list);
    }

//    @Override
//    public Result upload(MultipartFile file) {
//        try {
//            StorePath storePath = fastFileStorageClient.uploadFile(file.getInputStream(),
//                    file.getSize(),
//                    file.getOriginalFilename().split("\\.")[1], null);
//            return Result.success("http://49.235.108.160:8888/"+storePath.getFullPath());
//        } catch (IOException e) {
//           return Result.error("上传失败");
//        }
//    }
}
