package com.muyu.cloud.mart.service.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import com.muyu.cloud.mart.utils.*;
import com.muyu.cloud.mart.mapper.MarketMapper;
import com.muyu.cloud.mart.service.MarketService;
import com.muyu.common.core.domain.Result;
import com.muyu.domain.Birthday;
import com.muyu.domain.Market;
import com.muyu.domain.PhonePlace;
import com.muyu.domain.Postcode;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import static com.muyu.cloud.mart.config.IPLocation.params;
import static com.muyu.common.core.utils.PageUtils.startPage;

/**
 * @Author：chaiyapeng
 * @Package：com.muyu.cloud.etl.service.impl
 * @Project：cloud-mart
 * @name：MarketServiceImpl
 * @Date：2024/8/21 21:54
 */
@Service
@Log4j2
public class MarketServiceImpl extends ServiceImpl<MarketMapper, Market> implements MarketService {

    @Autowired
    private MarketMapper marketMapper;
    @Autowired
    private RedisTemplate<String,String>redisTemplate;

    @Override
    public List<Market> findMarketList() {
        if (redisTemplate.hasKey("list")){
            List<String> list = redisTemplate.opsForList().range("list", 0, -1);
            ArrayList<Market> markets = new ArrayList<>();
            for (String s : list) {
                markets.add(JSON.parseObject(s, Market.class));
            }
            return markets;
        }
        startPage();
//        List<Market> list = marketService.findMarketList();
        List<Market> list = marketMapper.selectList(null);
        for (Market market1 : list) {
            redisTemplate.opsForList().rightPush("list", JSON.toJSONString(market1));
        }
        return list;
    }
//    public static final PhoneNumberOfflineGeocoder GEOCODER = PhoneNumberOfflineGeocoder.getInstance();

    /**
     * 手机号查询归属地
     * @param tel
     */
    @Override
    public Result getPhonePlace(String tel) {
        PhonePlace phonePlace = MobileLocation.queryMobileLocation(tel);
        return Result.success(phonePlace);
    }

    /**
     * IP查询归属地
     * @param ip
     * @return
     */
    @Override
    public Result getIpPlace(String ip) {
        StringBuffer stringBuffer = IPLocation.queryIPLocation(ip);
        return Result.success(stringBuffer);
    }
    /**
     * 新闻头条
     * @return
     */
    @Override
    public Result getHeadlines() {
        StringBuffer stringBuffer = Headlines.queryHeadlines();
        return Result.success(stringBuffer);
    }
    /**
     * 气象预警
     */
    @Override
    public Result getWeather() {
        StringBuffer stringBuffer = Weather.queryWeather();
        return Result.success(stringBuffer);
    }
    /**
     * 生辰助手
     */
    @Override
    public Result getBirthday(Birthday birthday) {
        StringBuffer stringBuffer = BirthdayHelper.queryBirthday(birthday);
        return Result.success(stringBuffer);
    }
    /**
     * 邮编查询
     */
    @Override
    public Result getPostcode(Postcode postcode) {
        StringBuffer stringBuffer = PostcodeInquire.queryPostcode(postcode);
        return Result.success(stringBuffer);
    }
}
