package com.muyu.cloud.mart.utils;





import com.muyu.domain.PhonePlace;
import net.sf.json.JSONObject;

import java.io.*;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.Map;

/**
 * 手机号查询归属地接口
 */
public class MobileLocation {
    // 手机归属地查询接口地址
//     http://apis.juhe.cn/mobile/get  http://127.0.0.1:8369/query?mobile
    public static String API_URL = "http://apis.juhe.cn/mobile/get";
    // 接口请求Key
    public static String API_KEY = "8e5493da8edee8e42831574b9a2c3492";


    /**
     * 根据手机号码/手机号码前7位查询号码归属地
     * @param tel
     */
    public static PhonePlace queryMobileLocation(String tel)
    {
        Map<String, Object> params = new HashMap<>();//组合参数
        params.put("phone", tel);
        params.put("key", API_KEY);
        String queryParams = urlencode(params);
        PhonePlace phonePlace = new PhonePlace();

        String response = doGet(API_URL, queryParams);
        try {
            JSONObject jsonObject = JSONObject.fromObject(response);
            int error_code = jsonObject.getInt("error_code");
            if (error_code == 0) {
                System.out.println("调用接口成功");

                JSONObject result = jsonObject.getJSONObject("result");

                phonePlace.setProvince(result.getString("province"));
                phonePlace.setCity(result.getString("city"));
                phonePlace.setAreacode(result.getString("areacode"));
                phonePlace.setZip(result.getString("zip"));
                phonePlace.setCompany(result.getString("company"));

                System.out.printf("省份：%s%n", result.getString("province"));
                System.out.printf("城市：%s%n", result.getString("city"));
                System.out.printf("区号：%s%n", result.getString("areacode"));
                System.out.printf("邮编：%s%n", result.getString("zip"));
                System.out.printf("运营商：%s%n", result.getString("company"));

            } else {
                System.out.println("调用接口失败：" + jsonObject.getString("reason"));
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return phonePlace;
    }

    /**
     * get方式的http请求
     *
     * @param httpUrl 请求地址
     * @return 返回结果
     */
    public static String doGet(String httpUrl, String queryParams) {
        HttpURLConnection connection = null;
        InputStream inputStream = null;
        BufferedReader bufferedReader = null;
        String result = null;// 返回结果字符串
        try {
            // 创建远程url连接对象
            URL url = new URL(new StringBuffer(httpUrl).append("?").append(queryParams).toString());
            // 通过远程url连接对象打开一个连接，强转成httpURLConnection类
            connection = (HttpURLConnection) url.openConnection();
            // 设置连接方式：get
            connection.setRequestMethod("GET");
            // 设置连接主机服务器的超时时间：15000毫秒
            connection.setConnectTimeout(5000);
            // 设置读取远程返回的数据时间：60000毫秒
            connection.setReadTimeout(6000);
            // 发送请求
            connection.connect();
            // 通过connection连接，获取输入流
            if (connection.getResponseCode() == 200) {
                inputStream = connection.getInputStream();
                // 封装输入流，并指定字符集
                bufferedReader = new BufferedReader(new InputStreamReader(inputStream, StandardCharsets.UTF_8));
                // 存放数据
                StringBuilder sbf = new StringBuilder();
                String temp;
                while ((temp = bufferedReader.readLine()) != null) {
                    sbf.append(temp);
                    sbf.append(System.getProperty("line.separator"));
                }
                result = sbf.toString();
            }
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            // 关闭资源
            if (null != bufferedReader) {
                try {
                    bufferedReader.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            if (null != inputStream) {
                try {
                    inputStream.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            if (connection != null) {
                connection.disconnect();// 关闭远程连接
            }
        }
        return result;
    }

    /**
     * 将map型转为请求参数型
     *
     * @param data
     * @return
     */
    public static String urlencode(Map<String, ?> data) {
        StringBuilder sb = new StringBuilder();
        for (Map.Entry<String, ?> i : data.entrySet()) {
            try {
                sb.append(i.getKey()).append("=").append(URLEncoder.encode(i.getValue() + "", "UTF-8")).append("&");
            } catch (UnsupportedEncodingException e) {
                e.printStackTrace();
            }
        }
        String result = sb.toString();
        result = result.substring(0, result.lastIndexOf("&"));
        return result;
    }
}

